Examples gallery
################

.. admonition:: GWpy needs more examples!
    :class: seealso

    The GWpy project needs more real-life worked examples to demonstrate
    the full range of functionality that is available.

    If you use GWpy for your research, please consider suggesting a new
    example to be included in the documentation.

    To make a suggestion, please open an issue at

    https://gitlab.com/gwpy/gwpy/-/issues/new?issuable_template=Example

    If you have a script that can be converted directly into an example
    please consider opening a
    `merge request <https://gitlab.com/gwpy/gwpy/-/merge_requests/new>`__
    to add it to this gallery.
